@@ -17,6 +17,7 @@
 import sys
 import os
 import re
+from calculate.lib.datavars import DataVarsError
 from calculate.lib.cl_template import TemplateFormat
 import hashlib
 
@@ -57,8 +58,8 @@ class backgrounds(TemplateFormat):
     def setPrefix(self, prefix):
         self.prefix = prefix
 
-    def getImageMD5(self, source):
-        return hashlib.md5(readFile(source)).hexdigest()
+    def getImageMD5(self, source, resolutions=()):
+        return hashlib.md5(readFile(source)+"\n".join(resolutions)).hexdigest()
 
     def setStretch(self, stretch):
         self.stretch = stretch
@@ -116,11 +117,6 @@ class backgrounds(TemplateFormat):
                                   re.sub("[-._]+$", "", prefix))
         else:
             md5_fn = os.path.join(workdir, self.fallback_md5fn)
-        image_md5 = self.getImageMD5(source)
-        if os.path.exists(md5_fn):
-            md5sum = readFile(md5_fn).strip()
-            if md5sum == image_md5:
-                return ""
         self.source_width, self.source_height = \
             self.get_image_resolution(source)
         if not self.source_width:
@@ -134,7 +130,12 @@ class backgrounds(TemplateFormat):
         image_files = []
         resolutions = [x.strip() for x in text_list
                        if not x.startswith("#") and x.strip()]
-        only_one = len(resolutions) == 1
+        image_md5 = self.getImageMD5(source, resolutions=resolutions)
+        if os.path.exists(md5_fn):
+            md5sum = readFile(md5_fn).strip()
+            if md5sum == image_md5:
+                return ""
+        only_one = len(resolutions) == 1 and self.text.strip()
         if only_one:
             removed_files = [pathJoin(workdir, prefix)]
         else:
